module FileTree
  module ContentGenerator
    LETTERS = ["a".."z", "A".."Z", "0".."9", " ", "\n", "_", "*"].map{|i| Array(i)}.flatten
    CONTENT_TYPES = [:binary, :text, :empty]

    def self.create(type)
      type = CONTENT_TYPES.sample if type == :random

      case type
        when :binary
          create_binary_content
        when :text
          create_text_content
        when :empty
          ""
        else
          raise(ArgumentError, "Unsupported content type: #{type}")
      end
    end

    def self.create_binary_content
      Random.new.bytes(random_file_size)
    end

    def self.create_text_content
      (1..random_file_size).map{LETTERS.sample}.join
    end

    def self.random_file_size
      rand(Defaults.min_file_size..Defaults.max_file_size)
    end
  end
end
